@@ -348,7 +348,10 @@ canl_cred_set_extension(canl_ctx ctx, canl_cred cred, X509_EXTENSION *cert_ext)
 
     if (!cred)
         return set_error(cc, EINVAL, POSIX_ERROR, "Cred. handler"
-                " not initialized" ); 
+                " not initialized" );
+
+    if (!cert_ext)
+        return 0; //TODO is it error? I guesss no. 
 
     if (!crd->c_cert_ext)
        crd->c_cert_ext = sk_X509_EXTENSION_new_null();
@@ -382,8 +385,9 @@ canl_cred_sign_proxy(canl_ctx ctx, canl_cred signer_cred,
     creds *signer_crd = (creds*) signer_cred;
     creds *proxy_crd = (creds*) proxy_cred;
     int err = 0;
+#if 0
     int key_size = 0;
-    enum canl_cert_type cert_type = 0;
+#endif
     int proxyver;
 
     if (!ctx)
@@ -396,6 +400,10 @@ canl_cred_sign_proxy(canl_ctx ctx, canl_cred signer_cred,
         return set_error(cc, EINVAL, POSIX_ERROR, "Proxy cred. handler"
                 " not initialized" );
 
+#if 0
+#This part of the code was mentioned to check for the unpropriate key size with
+#respect to the certificate validity period. The LIFETIME_TRESHOLD should
+# not be hardwired in the code (or may not be there at all).   
     if (proxy_crd->c_req) {
         EVP_PKEY *tmp_key = X509_REQ_get_pubkey(proxy_crd->c_req);
         if (!tmp_key)
@@ -409,6 +417,7 @@ canl_cred_sign_proxy(canl_ctx ctx, canl_cred signer_cred,
                     "sign cert. request -the key is too short with "
                    "respect to cert. lifetime");
     }
+#endif
 
     switch (proxy_crd->c_type){
         case CANL_EEC:
@@ -716,7 +725,7 @@ canl_verify_chain(canl_ctx ctx, X509 *ucert, STACK_OF(X509) *cert_chain,
     pvd = canl_pvd_setup_initializers(cadir, NULL, 0);
     ret = proxy_verify_cert_chain(ucert, cert_chain, pvd);
     canl_pvd_destroy_initializers(pvd);
-    if (ret)
+    if (!ret)
         /* This will be ommited when proxy_verify_cert sets errors itself or
            propagate them out. */
         return set_error(ctx, CANL_ERR_unknown, CANL_ERROR, "Certificate chain"
